classpath-patches
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[cp-patches] FYI: API doc fixes for java.text.*


From: David Gilbert
Subject: [cp-patches] FYI: API doc fixes for java.text.*
Date: Sat, 23 Jul 2005 21:26:18 +0000
User-agent: Mozilla Thunderbird 1.0.2 (X11/20050426)

I committed this patch:

2005-07-23  David Gilbert  <address@hidden>

        * java/text/AttributedString.java: API doc fixes,
        * java/text/ChoiceFormat.java: likewise,
        * java/text/CollationElementIterator.java: likewise,
        * java/text/CollationKey.java: likewise,
        * java/text/Collator.java: likewise,
        * java/text/DateFormat.java: likewise,
        * java/text/DateFormatSymbols.java: likewise,
        * java/text/DecimalFormatSymbols.java: likewise,
        * java/text/MessageFormat.java: likewise,
        * java/text/NumberFormat.java: likewise,
        * java/text/ParseException.java: likewise,
        * java/text/SimpleDateFormat.java: likewise,
        * java/text/StringCharacterIterator.java: likewise.

Regards,

Dave Gilbert

Index: java/text/AttributedString.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/text/AttributedString.java,v
retrieving revision 1.11
diff -u -r1.11 AttributedString.java
--- java/text/AttributedString.java     2 Jul 2005 20:32:41 -0000       1.11
+++ java/text/AttributedString.java     23 Jul 2005 20:18:12 -0000
@@ -342,7 +342,8 @@
   * @param begin_index The beginning index.
   * @param end_index The ending index
   *
-  * @param IllegalArgumentException If the list is <code>null</code> or the 
subrange is not valid.
+  * @throws IllegalArgumentException If the list is <code>null</code> or the 
+  * subrange is not valid.
   */
 public void
 addAttributes(Map attributes, int begin_index, int end_index)
Index: java/text/ChoiceFormat.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/text/ChoiceFormat.java,v
retrieving revision 1.12
diff -u -r1.12 ChoiceFormat.java
--- java/text/ChoiceFormat.java 2 Jul 2005 20:32:41 -0000       1.12
+++ java/text/ChoiceFormat.java 23 Jul 2005 20:18:12 -0000
@@ -86,7 +86,7 @@
    * object based on the specified pattern. This pattern is of the form 
    * "term#string|term#string...".  For example "1#Sunday|2#Monday|#Tuesday".
    *
-   * @param pattern The pattern of terminators and format strings.
+   * @param newPattern The pattern of terminators and format strings.
    *
    * @exception IllegalArgumentException If the pattern is not valid
    */
@@ -170,7 +170,7 @@
    * This is the same pattern type used by the <code>applyPattern</code>
    * method.
    *
-   * @param pattern The pattern of terminators and format strings.
+   * @param newPattern The pattern of terminators and format strings.
    *
    * @exception IllegalArgumentException If the pattern is not valid
    */
@@ -229,10 +229,11 @@
    * <code>StringBuffer</code> based on the supplied <code>long</code>
    * argument.
    *
-   * @param number The number used for determine (based on the range
+   * @param num The number used for determine (based on the range
    *               terminators) which format string to append. 
-   * @param sb The <code>StringBuffer</code> to append the format string to.
-   * @param status Unused.
+   * @param appendBuf The <code>StringBuffer</code> to append the format 
string 
+   *                  to.
+   * @param pos Unused.
    *
    * @return The <code>StringBuffer</code> with the format string appended.
    */
@@ -247,10 +248,10 @@
    * <code>StringBuffer</code> based on the supplied <code>double</code>
    * argument.
    *
-   * @param number The number used for determine (based on the range
+   * @param num The number used for determine (based on the range
    *               terminators) which format string to append. 
-   * @param sb The <code>StringBuffer</code> to append the format string to.
-   * @param status Unused.
+   * @param appendBuf The <code>StringBuffer</code> to append the format 
string to.
+   * @param pos Unused.
    *
    * @return The <code>StringBuffer</code> with the format string appended.
    */
@@ -333,7 +334,7 @@
    * double less than the specified double will be returned.
    *
    * @param d The specified double
-   * @param positive <code>true</code> to return the next highest
+   * @param next <code>true</code> to return the next highest
    *                 double, <code>false</code> otherwise. 
    *
    * @return The next highest or lowest double value.
Index: java/text/CollationElementIterator.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/text/CollationElementIterator.java,v
retrieving revision 1.23
diff -u -r1.23 CollationElementIterator.java
--- java/text/CollationElementIterator.java     2 Jul 2005 20:32:41 -0000       
1.23
+++ java/text/CollationElementIterator.java     23 Jul 2005 20:18:13 -0000
@@ -177,9 +177,11 @@
    * This method returns the primary order value for the given collation
    * value.
    *
-   * @param value The collation value returned from <code>next()</code> or 
<code>previous()</code>.
+   * @param order The collation value returned from <code>next()</code> or 
+   *              <code>previous()</code>.
    *
-   * @return The primary order value of the specified collation value.  This 
is the high 16 bits.
+   * @return The primary order value of the specified collation value.  This is
+   *         the high 16 bits.
    */
   public static int primaryOrder(int order)
   {
@@ -201,9 +203,11 @@
    * This method returns the secondary order value for the given collation
    * value.
    *
-   * @param value The collation value returned from <code>next()</code> or 
<code>previous()</code>.
+   * @param order The collation value returned from <code>next()</code> or 
+   *              <code>previous()</code>.
    *
-   * @return The secondary order value of the specified collation value.  This 
is the bits 8-15.
+   * @return The secondary order value of the specified collation value.  This 
+   *         is the bits 8-15.
    */
   public static short secondaryOrder(int order)
   {
@@ -215,9 +219,11 @@
    * This method returns the tertiary order value for the given collation
    * value.
    *
-   * @param value The collation value returned from <code>next()</code> or 
<code>previous()</code>.
+   * @param order The collation value returned from <code>next()</code> or 
+   *              <code>previous()</code>.
    *
-   * @return The tertiary order value of the specified collation value.  This 
is the low eight bits.
+   * @return The tertiary order value of the specified collation value.  This 
+   *         is the low eight bits.
    */
   public static short tertiaryOrder(int order)
   {
@@ -458,7 +464,7 @@
    *
    * @param value The collation order value
    *
-   * @param The maximum length of an expansion sequence.
+   * @return The maximum length of an expansion sequence.
    */
   public int getMaxExpansion(int value)
   {
Index: java/text/CollationKey.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/text/CollationKey.java,v
retrieving revision 1.14
diff -u -r1.14 CollationKey.java
--- java/text/CollationKey.java 2 Jul 2005 20:32:41 -0000       1.14
+++ java/text/CollationKey.java 23 Jul 2005 20:18:13 -0000
@@ -190,7 +190,7 @@
   /**
    * This method returns the collation bit sequence as a byte array.
    *
-   * @param A byte array containing the collation bit sequence.
+   * @return A byte array containing the collation bit sequence.
    */
   public byte[] toByteArray()
   {
Index: java/text/Collator.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/text/Collator.java,v
retrieving revision 1.14
diff -u -r1.14 Collator.java
--- java/text/Collator.java     2 Jul 2005 20:32:41 -0000       1.14
+++ java/text/Collator.java     23 Jul 2005 20:18:14 -0000
@@ -150,8 +150,8 @@
    * <code>Collator</code> and the strength and decomposition rules in
    * effect.
    *
-   * @param str1 The first object to compare
-   * @param str2 The second object to compare
+   * @param source The first object to compare
+   * @param target The second object to compare
    *
    * @return A negative integer if str1 &lt; str2, 0 if str1 == str2, or
    * a positive integer if str1 &gt; str2. 
@@ -164,8 +164,8 @@
    * equal to, or greater than the second argument.  These two objects
    * must be <code>String</code>'s or an exception will be thrown.
    *
-   * @param obj1 The first object to compare
-   * @param obj2 The second object to compare
+   * @param o1 The first object to compare
+   * @param o2 The second object to compare
    *
    * @return A negative integer if obj1 &lt; obj2, 0 if obj1 == obj2, or
    * a positive integer if obj1 &gt; obj2. 
@@ -208,8 +208,8 @@
    * according to the collation rules for the locale of this object and
    * the current strength and decomposition settings.
    *
-   * @param str1 The first <code>String</code> to compare
-   * @param str2 The second <code>String</code> to compare
+   * @param source The first <code>String</code> to compare
+   * @param target The second <code>String</code> to compare
    *
    * @return <code>true</code> if the two strings are equal,
    * <code>false</code> otherwise. 
@@ -256,7 +256,7 @@
    * comparisons against a string might be performed multiple times, such
    * as during a sort operation.
    *
-   * @param str The <code>String</code> to convert.
+   * @param source The <code>String</code> to convert.
    *
    * @return A <code>CollationKey</code> for the specified <code>String</code>.
    */
@@ -292,7 +292,7 @@
    * specified locale.  If no <code>Collator</code> exists for the desired
    * locale, a <code>Collator</code> for the default locale will be returned.
    *
-   * @param locale The desired localed to load a <code>Collator</code> for.
+   * @param loc The desired localed to load a <code>Collator</code> for.
    *
    * @return A <code>Collator</code> for the requested locale
    */
@@ -347,7 +347,7 @@
    * exception will be thrown.  See the documentation for those
    * contants for an explanation of this setting.
    *
-   * @param decmp The new decomposition setting.
+   * @param mode The new decomposition setting.
    *
    * @exception IllegalArgumentException If the requested
    * decomposition setting is not valid.
Index: java/text/DateFormat.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/text/DateFormat.java,v
retrieving revision 1.20
diff -u -r1.20 DateFormat.java
--- java/text/DateFormat.java   2 Jul 2005 20:32:41 -0000       1.20
+++ java/text/DateFormat.java   23 Jul 2005 20:18:15 -0000
@@ -442,9 +442,9 @@
    * thrown.
    *
    * @param obj The <code>Object</code> to format.
-   * @param toAppendTo The <code>StringBuffer</code> to append the resultant
+   * @param buf The <code>StringBuffer</code> to append the resultant
    * <code>String</code> to.
-   * @param fieldPosition Is updated to the start and end index of the
+   * @param pos Is updated to the start and end index of the
    * specified field.
    *
    * @return The <code>StringBuffer</code> supplied on input, with the
@@ -479,9 +479,9 @@
    * to the specified <code>StringBuffer</code>.
    *
    * @param date The <code>Date</code> value to format.
-   * @param toAppendTo The <code>StringBuffer</code> to append the resultant
+   * @param buf The <code>StringBuffer</code> to append the resultant
    * <code>String</code> to.
-   * @param fieldPosition Is updated to the start and end index of the
+   * @param pos Is updated to the start and end index of the
    * specified field.
    *
    * @return The <code>StringBuffer</code> supplied on input, with the
@@ -643,7 +643,7 @@
    * localed will be used in place of the default.
    *
    * @param style The type of formatting to perform. 
-   * @param aLocale The desired locale.
+   * @param loc The desired locale.
    * 
    * @return A new <code>DateFormat</code> instance.
    */
@@ -744,7 +744,7 @@
    * localed will be used in place of the default.
    *
    * @param style The type of formatting to perform. 
-   * @param aLocale The desired locale.
+   * @param loc The desired locale.
    * 
    * @return A new <code>DateFormat</code> instance.
    */
@@ -818,7 +818,7 @@
    * starting parse position on method entry and the ending parse
    * position on method exit.
    *
-   * @param text The string to parse.
+   * @param source The string to parse.
    * @param pos The starting parse position in entry, the ending parse
    * position on exit.
    *
@@ -848,7 +848,7 @@
    * This method specified the <code>Calendar</code> that should be used 
    * by this object to parse/format datetimes.
    *
-   * @param The new <code>Calendar</code> for this object.
+   * @param calendar The new <code>Calendar</code> for this object.
    *
    * @see java.util.Calendar
    */
@@ -873,7 +873,7 @@
    * This method specifies the <code>NumberFormat</code> object that should
    * be used by this object to parse/format times.
    *
-   * @param The <code>NumberFormat</code> in use by this object.
+   * @param numberFormat The <code>NumberFormat</code> in use by this object.
    */
   public void setNumberFormat (NumberFormat numberFormat)
   {
@@ -883,7 +883,7 @@
   /**
    * This method sets the time zone that should be used by this object.
    *
-   * @param The new time zone.
+   * @param timeZone The new time zone.
    */
   public void setTimeZone (TimeZone timeZone)
   {
Index: java/text/DecimalFormatSymbols.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/text/DecimalFormatSymbols.java,v
retrieving revision 1.19
diff -u -r1.19 DecimalFormatSymbols.java
--- java/text/DecimalFormatSymbols.java 2 Jul 2005 20:32:41 -0000       1.19
+++ java/text/DecimalFormatSymbols.java 23 Jul 2005 20:18:17 -0000
@@ -139,7 +139,7 @@
    * locales (those with no specified country), such as
    * <code>Locale.ENGLISH</code>.
    *
-   * @param locale The local to load symbols for.
+   * @param loc The local to load symbols for.
    * @throws NullPointerException if the locale is null.
    */
   public DecimalFormatSymbols (Locale loc)
@@ -422,7 +422,7 @@
   /**
    * This method sets the currency symbol to the specified value.
    *
-   * @param currencySymbol The new currency symbol
+   * @param currency The new currency symbol
    */
   public void setCurrencySymbol (String currency)
   {
@@ -432,7 +432,7 @@
   /**
    * This method sets the decimal point character to the specified value.
    *
-   * @param decimalSeparator The new decimal point character
+   * @param decimalSep The new decimal point character
    */
   public void setDecimalSeparator (char decimalSep)
   {
@@ -464,7 +464,7 @@
   /**
    * This method sets the character used to separate groups of digits.
    *
-   * @param groupingSeparator The character used to separate groups of digits.
+   * @param groupSep The character used to separate groups of digits.
    */
   public void setGroupingSeparator (char groupSep)
   {
@@ -523,8 +523,7 @@
    * This method sets the character used for the decimal point in currency
    * values.
    *
-   * @param monetarySeparator The decimal point character used in
-   *                          currency values. 
+   * @param decimalSep The decimal point character used in currency values. 
    */
   public void setMonetaryDecimalSeparator (char decimalSep)
   {
@@ -535,7 +534,7 @@
    * This method sets the string used to represent the NaN (not a
    * number) value. 
    *
-   * @param NaN The string used to represent NaN
+   * @param nan The string used to represent NaN
    */
   public void setNaN (String nan)
   {
@@ -546,7 +545,7 @@
    * This method sets the character used to separate positive and negative
    * subpatterns in a format pattern.
    *
-   * @param patternSeparator The character used to separate positive and
+   * @param patternSep The character used to separate positive and
    * negative subpatterns in a format pattern.
    */
   public void setPatternSeparator (char patternSep)
Index: java/text/MessageFormat.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/text/MessageFormat.java,v
retrieving revision 1.21
diff -u -r1.21 MessageFormat.java
--- java/text/MessageFormat.java        2 Jul 2005 20:32:41 -0000       1.21
+++ java/text/MessageFormat.java        23 Jul 2005 20:18:17 -0000
@@ -334,7 +334,7 @@
   /**
    * Applies the specified pattern to this MessageFormat.
    *
-   * @param aPattern The Pattern
+   * @param newPattern The Pattern
    */
   public void applyPattern (String newPattern)
   {
@@ -378,7 +378,6 @@
   /**
    * A convinience method to format patterns.
    *
-   * @param aPattern The pattern used when formatting.
    * @param arguments The array containing the objects to be formatted.
    */
   public AttributedCharacterIterator formatToCharacterIterator (Object 
arguments)
@@ -394,7 +393,7 @@
   /**
    * A convinience method to format patterns.
    *
-   * @param aPattern The pattern used when formatting.
+   * @param pattern The pattern used when formatting.
    * @param arguments The array containing the objects to be formatted.
    */
   public static String format (String pattern, Object arguments[])
@@ -408,8 +407,8 @@
   /**
    * Returns the pattern with the formatted objects.
    *
-   * @param source The array containing the objects to be formatted.
-   * @param result The StringBuffer where the text is appened.
+   * @param arguments The array containing the objects to be formatted.
+   * @param appendBuf The StringBuffer where the text is appened.
    * @param fp A FieldPosition object (it is ignored).
    */
   public final StringBuffer format (Object arguments[], StringBuffer appendBuf,
@@ -709,8 +708,8 @@
    * Sets the format for the argument at an specified
    * index.
    *
-   * @param index The index.
-   * @format The Format object.
+   * @param variableNum The index.
+   * @param newFormat The Format object.
    */
   public void setFormat (int variableNum, Format newFormat)
   {
@@ -720,7 +719,7 @@
   /**
    * Sets the formats for the arguments.
    *
-   * @param formats An array of Format objects.
+   * @param newFormats An array of Format objects.
    */
   public void setFormats (Format[] newFormats)
   {
@@ -735,7 +734,7 @@
   /**
    * Sets the locale.
    *
-   * @param locale A Locale
+   * @param loc A Locale
    */
   public void setLocale (Locale loc)
   {
Index: java/text/NumberFormat.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/text/NumberFormat.java,v
retrieving revision 1.17
diff -u -r1.17 NumberFormat.java
--- java/text/NumberFormat.java 2 Jul 2005 20:32:41 -0000       1.17
+++ java/text/NumberFormat.java 23 Jul 2005 20:18:19 -0000
@@ -237,7 +237,8 @@
    * a <code>StringBuffer</code>.
    * 
    * @param number The <code>double</code> to format.
-   * @param sb The <code>StringBuffer</code> to append the formatted number to.
+   * @param sbuf The <code>StringBuffer</code> to append the formatted number 
+   *             to.
    * @param pos The desired <code>FieldPosition</code>.
    *
    * @return The <code>StringBuffer</code> with the appended number.
@@ -250,7 +251,8 @@
    * a <code>StringBuffer</code>.
    * 
    * @param number The <code>long</code> to format.
-   * @param sb The <code>StringBuffer</code> to append the formatted number to.
+   * @param sbuf The <code>StringBuffer</code> to append the formatted number 
+   *             to.
    * @param pos The desired <code>FieldPosition</code>.
    *
    * @return The <code>StringBuffer</code> with the appended number.
@@ -371,7 +373,7 @@
    * will be a concrete subclass of <code>NumberFormat</code>, but the 
    * actual class returned is dependent on the locale.
    *
-   * @param locale The desired locale.
+   * @param loc The desired locale.
    *
    * @return An instance of the default <code>NumberFormat</code> class.
    */
@@ -434,8 +436,6 @@
    * will be a concrete subclass of <code>NumberFormat</code>, but the 
    * actual class returned is dependent on the locale.
    *
-   * @param locale The desired locale.
-   *
    * @return An instance of the default <code>NumberFormat</code> class.
    */
   public static final NumberFormat getNumberInstance ()
@@ -502,7 +502,7 @@
    * This method returns an instance of <code>NumberFormat</code> suitable
    * for formatting and parsing percentage values in the specified locale.
    *
-   * @param locale The desired locale.
+   * @param loc The desired locale.
    *
    * @return An instance of <code>NumberFormat</code> for handling percentages.
    */
@@ -571,8 +571,8 @@
    * <code>Double</code>.    If no number can be parsed, no exception is
    * thrown.  Instead, the parse position remains at its initial index.
    *
-   * @param str The string to parse.
-   * @param pp The desired <code>ParsePosition</code>.
+   * @param sourceStr The string to parse.
+   * @param pos The desired <code>ParsePosition</code>.
    *
    * @return The parsed <code>Number</code>
    */
@@ -584,7 +584,7 @@
    * <code>Double</code>.  If no number can be parsed, an exception will be
    * thrown.
    *
-   * @param str The string to parse.
+   * @param sourceStr The string to parse.
    *
    * @return The parsed <code>Number</code>
    *
@@ -610,8 +610,8 @@
    * <code>Double</code>.    If no number can be parsed, no exception is
    * thrown.  Instead, the parse position remains at its initial index.
    *
-   * @param str The string to parse.
-   * @param pp The desired <code>ParsePosition</code>.
+   * @param sourceStr The string to parse.
+   * @param pos The desired <code>ParsePosition</code>.
   *
   * @return The parsed <code>Object</code>
   */
@@ -629,7 +629,7 @@
    * might appear as "1,000,000".  (Both of these assume the US English
    * locale).
    *
-   * @param groupingUsed <code>true</code> to enable grouping,
+   * @param newValue <code>true</code> to enable grouping,
    *                     <code>false</code> to disable it. 
    */
   public void setGroupingUsed (boolean newValue)
@@ -643,11 +643,11 @@
    * current minimum allowed digits, the minimum allowed digits value will
    * be lowered to be equal to the new maximum allowed digits value.
    *
-   * @param maximumFractionDigits The new maximum fraction digits value.
+   * @param digits The new maximum fraction digits value.
    */
-  public void setMaximumFractionDigits (int newValue)
+  public void setMaximumFractionDigits (int digits)
   {
-    maximumFractionDigits = newValue;
+    maximumFractionDigits = digits;
     if (getMinimumFractionDigits () > maximumFractionDigits)
       setMinimumFractionDigits (maximumFractionDigits);
   }
@@ -658,11 +658,11 @@
    * current minimum allowed digits, the minimum allowed digits value will
    * be lowered to be equal to the new maximum allowed digits value.
    *
-   * @param maximumIntegerDigits The new maximum integer digits value.
+   * @param digits The new maximum integer digits value.
    */
-  public void setMaximumIntegerDigits (int newValue)
+  public void setMaximumIntegerDigits (int digits)
   {
-    maximumIntegerDigits = newValue;
+    maximumIntegerDigits = digits;
     if (getMinimumIntegerDigits () > maximumIntegerDigits)
       setMinimumIntegerDigits (maximumIntegerDigits);
   }
@@ -673,11 +673,11 @@
    * current maximum allowed digits, the maximum allowed digits value will
    * be raised to be equal to the new minimum allowed digits value.
    *
-   * @param minimumFractionDigits The new minimum fraction digits value.
+   * @param digits The new minimum fraction digits value.
    */
-  public void setMinimumFractionDigits (int newValue)
+  public void setMinimumFractionDigits (int digits)
   {
-    minimumFractionDigits = newValue;
+    minimumFractionDigits = digits;
     if (getMaximumFractionDigits () < minimumFractionDigits)
       setMaximumFractionDigits (minimumFractionDigits);
   }
@@ -688,11 +688,11 @@
    * current maximum allowed digits, the maximum allowed digits value will
    * be raised to be equal to the new minimum allowed digits value.
    *
-   * @param minimumIntegerDigits The new minimum integer digits value.
+   * @param digits The new minimum integer digits value.
    */
-  public void setMinimumIntegerDigits (int newValue)
+  public void setMinimumIntegerDigits (int digits)
   {
-    minimumIntegerDigits = newValue;
+    minimumIntegerDigits = digits;
     if (getMaximumIntegerDigits () < minimumIntegerDigits)
       setMaximumIntegerDigits (minimumIntegerDigits);
   }
@@ -701,7 +701,7 @@
    * This method sets the parsing behavior of this object to parse only 
    * integers or not.
    *
-   * @param parseIntegerOnly <code>true</code> to parse only integers,
+   * @param value <code>true</code> to parse only integers,
    *                         <code>false</code> otherwise. 
    */
   public void setParseIntegerOnly (boolean value)
Index: java/text/ParseException.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/text/ParseException.java,v
retrieving revision 1.7
diff -u -r1.7 ParseException.java
--- java/text/ParseException.java       2 Jul 2005 20:32:41 -0000       1.7
+++ java/text/ParseException.java       23 Jul 2005 20:18:19 -0000
@@ -65,7 +65,7 @@
    * This method initializes a new instance of <code>ParseException</code>
    * with a detailed error message and a error position.
    *
-   * @param msg the descriptive message describing the error
+   * @param s the descriptive message describing the error
    * @param offset the position where the error was encountered
    */
   public ParseException(String s, int offset)
Index: java/text/SimpleDateFormat.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/text/SimpleDateFormat.java,v
retrieving revision 1.48
diff -u -r1.48 SimpleDateFormat.java
--- java/text/SimpleDateFormat.java     13 Jul 2005 23:22:31 -0000      1.48
+++ java/text/SimpleDateFormat.java     23 Jul 2005 20:18:20 -0000
@@ -180,8 +180,8 @@
    * years to be interpreted as representing
    * the years between 2004 and 2104.
    *
-   * @see get2DigitYearStart()
-   * @see set2DigitYearStart(java.util.Date)
+   * @see #get2DigitYearStart()
+   * @see #set2DigitYearStart(java.util.Date)
    * @see Date
    * @serial The start date of the century for parsing two digit years.
    *         May not be null.
@@ -192,8 +192,8 @@
    * The year at which interpretation of two
    * digit years starts.
    *
-   * @see get2DigitYearStart()
-   * @see set2DigitYearStart(java.util.Date)
+   * @see #get2DigitYearStart()
+   * @see #set2DigitYearStart(java.util.Date)
    * @serial Ignored.
    */
   private transient int defaultCentury;
@@ -204,10 +204,10 @@
    * stored in standardChars.  Localized patterns
    * are translated to this form.
    *
-   * @see applyPattern(String)
-   * @see applyLocalizedPattern(String)
-   * @see toPattern()
-   * @see toLocalizedPattern()
+   * @see #applyPattern(String)
+   * @see #applyLocalizedPattern(String)
+   * @see #toPattern()
+   * @see #toLocalizedPattern()
    * @serial The non-localized pattern string.  May not be null.
    */
   private String pattern;
@@ -611,7 +611,7 @@
    * <li>Is using the same century for two digit years.</li>
    * </ul>
    *
-   * @param obj The object to compare for equality against.
+   * @param o The object to compare for equality against.
    *
    * @return <code>true</code> if the specified object is equal to this object,
    * <code>false</code> otherwise.
Index: java/text/DateFormatSymbols.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/text/DateFormatSymbols.java,v
retrieving revision 1.18
diff -u -r1.18 DateFormatSymbols.java
--- java/text/DateFormatSymbols.java    2 Jul 2005 20:32:41 -0000       1.18
+++ java/text/DateFormatSymbols.java    23 Jul 2005 20:18:16 -0000
@@ -41,7 +41,6 @@
 import java.util.Locale;
 import java.util.MissingResourceException;
 import java.util.ResourceBundle;
-import java.util.StringTokenizer;
 
 /**
  * This class acts as container for locale specific date/time formatting
@@ -289,7 +288,7 @@
    * This is a two element <code>String</code> array indexed by
    * <code>Calendar.AM</code> and <code>Calendar.PM</code>
    *
-   * @param ampms The new list of AM/PM display strings.
+   * @param value The new list of AM/PM display strings.
    */
   public void setAmPmStrings (String[] value)
   {
@@ -302,11 +301,11 @@
    * This is a two element <code>String</code>
    * array indexed by <code>Calendar.BC</code> and <code>Calendar.AD</code>.
    *
    * @param eras The new list of era disply strings.
    */
-  public void setEras (String[] value)
+  public void setEras (String[] labels)
   {
-    eras = value;
+    eras = labels;
   }
 
   /**
@@ -340,11 +339,11 @@
     * <li>17 - time zone (z)</li>
     * </ul>
     *
-    * @param localPatternChars The new format patter characters
+    * @param chars The new format pattern characters
     */
-  public void setLocalPatternChars (String value)
+  public void setLocalPatternChars (String chars)
   {
-    localPatternChars = value;
+    localPatternChars = chars;
   }
 
   /**
@@ -354,11 +353,11 @@
     * <code>Calendar.UNDECEMBER</code>.  Note that there are thirteen
     * elements because some calendars have thriteen months.
     *
     * @param months The list of month display strings.
     */
-  public void setMonths (String[] value)
+  public void setMonths (String[] labels)
   {
-    months = value;
+    months = labels;
   }
 
   /**
@@ -369,11 +368,11 @@
    * through <code>Calendar.UNDECEMBER</code>.  Note that there are thirteen
    * elements because some calendars have thirteen months.
    *
    * @param shortMonths The new list of abbreviated month display strings.
    */
-  public void setShortMonths (String[] value)
+  public void setShortMonths (String[] labels)
   {
-    shortMonths = value;
+    shortMonths = labels;
   }
 
   /**
@@ -384,11 +383,11 @@
    * through <code>Calendar.SATURDAY</code>.  Note that the first element
    * of this array is ignored.
    *
    * @param shortWeekdays This list of abbreviated weekday display strings.
    */
-  public void setShortWeekdays (String[] value)
+  public void setShortWeekdays (String[] labels)
   {
-    shortWeekdays = value;
+    shortWeekdays = labels;
   }
 
   /**
@@ -398,11 +397,11 @@
    * through <code>Calendar.SATURDAY</code>.  Note that the first element
    * of this array is ignored.
    *
    * @param weekdays This list of weekday display strings.
    */
-  public void setWeekdays (String[] value)
+  public void setWeekdays (String[] labels)
   {
-    weekdays = value;
+    weekdays = labels;
   }
 
   /**
@@ -418,11 +417,11 @@
    * <li>4 - the short name of the time zone (daylight savings time).</li>
    * </ul>
    *
    * @return The list of time zone display strings.
    */
-  public void setZoneStrings (String[][] value)
+  public void setZoneStrings (String[][] zones)
   {
-    zoneStrings = value;
+    zoneStrings = zones;
   }
 
   /* Does a "deep" equality test - recurses into arrays. */
@@ -492,7 +491,7 @@
   /**
    * Returns a new copy of this object.
    *
-   * @param A copy of this object
+   * @return A copy of this object
    */
   public Object clone ()
   {
@@ -302,11 +301,11 @@
    * array indexed by <code>Calendar.BC</code> and <code>Calendar.AD</code>.
    *
-   * @param eras The new list of era disply strings.
+   * @param labels The new list of era display strings.
    */
@@ -354,11 +353,11 @@
     * elements because some calendars have thriteen months.
     *
-    * @param months The list of month display strings.
+    * @param labels The list of month display strings.
     */
@@ -369,11 +368,11 @@
    * elements because some calendars have thirteen months.
    *
-   * @param shortMonths The new list of abbreviated month display strings.
+   * @param labels The new list of abbreviated month display strings.
    */
@@ -384,11 +383,11 @@
    * of this array is ignored.
    *
-   * @param shortWeekdays This list of abbreviated weekday display strings.
+   * @param labels This list of abbreviated weekday display strings.
    */
@@ -398,11 +397,11 @@
    * of this array is ignored.
    *
-   * @param weekdays This list of weekday display strings.
+   * @param labels This list of weekday display strings.
    */
@@ -418,11 +417,11 @@
    * </ul>
    *
-   * @return The list of time zone display strings.
+   * @params zones The list of time zone display strings.
    */
Index: java/text/StringCharacterIterator.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/text/StringCharacterIterator.java,v
retrieving revision 1.9
diff -u -r1.9 StringCharacterIterator.java
--- java/text/StringCharacterIterator.java      2 Jul 2005 20:32:41 -0000       
1.9
+++ java/text/StringCharacterIterator.java      23 Jul 2005 20:18:21 -0000
@@ -113,7 +113,7 @@
    * @param end The ending position in the character range.
    * @param index The initial index position.
    *
-   * @param IllegalArgumentException If any of the range values are
+   * @throws IllegalArgumentException If any of the range values are
    * invalid.
    */
   public StringCharacterIterator (String text, int begin, int end, int index)

reply via email to

[Prev in Thread] Current Thread [Next in Thread]